==> activity-center-api-0.8.2.9.y11-20171215.043629-7-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/ProbDto.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:Prob.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.dto<br>
 * Date:2017年3月29日下午8:54:03<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;
import cn.com.duiba.tuia.activity.center.api.common.Probability;
import cn.com.duiba.tuia.activity.center.api.constant.PageType;
import org.apache.commons.lang3.RandomUtils;

import java.util.List;

/**
 * ClassName: ProbDto <br/>
 * Function: 浮标跳转概率Dto. <br/>
 * Reason: . <br/>
 * date: 2017年3月29日 下午8:54:03 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class ProbDto extends BaseDto {

    private static final long serialVersionUID = 1L;
    /** actCenter:活动中心 概率. */
    private Probability       actCenter;
    /** mainMeet:主会场 概率. */
    private Probability       mainMeet;
    /** activity:活动 概率. */
    private Probability       activity;
    /** 直达变现页 概率.*/
    private Probability       directPage;

    /** url:活动 概率. */
    private Probability       url;

    private List<RateDto> urlList;

    /** 配置主会场页面概率.*/
    private List<RateDto> mainMeetList;

    /** 落地页url对应浮标. */
    private List<Long> buoyIdList;

    /** 配置直投页列表面概率.*/
    private List<RateDto> directPageList;

    public ProbDto() {
        super();
    }

    /**
     * 根据概率返回RateDto
     * @param list list
     * @param totalRate 总概率，没有则遍历list计算
     * @return RateDto
     */
    public static RateDto calRate(List<RateDto> list,Integer totalRate) {
        if (list == null || list.isEmpty()) {
            return null;
        }

        Integer total = totalRate;

        if (total == null) {
            total = sumRate(list);
        }

        if (total == null || total == 0) {
            return null;
        }

        int point = RandomUtils.nextInt(0, total);

        for (RateDto dto : list) {
            Integer rate = dto.getRate();
            if (rate == null || rate == 0) {
                continue;
            }
            if (rate >= point) {
                return dto;
            } else {
                point-=rate;
            }
        }
        return null;
    }

    /**
     * 计算概率和
     * @param list list
     * @return 概率和
     */
    public static Integer sumRate(List<RateDto> list) {
        int total = 0;
        if (list == null || list.isEmpty()) {
            return null;
        }
        for (RateDto dto : list) {
            Integer rate = dto.getRate();
            if (rate != null) {
                total += rate;
            }

        }
        return total;
    }

    public List<Long> getBuoyIdList() {
        return buoyIdList;
    }

    public void setBuoyIdList(List<Long> buoyIdList) {
        this.buoyIdList = buoyIdList;
    }

    public Probability getUrl() {
        return url;
    }

    public void setUrl(Probability url) {
        this.url = url;
    }

    public List<RateDto> getUrlList() {
        return urlList;
    }

    public void setUrlList(List<RateDto> urlList) {
        this.urlList = urlList;
    }

    public List<RateDto> getMainMeetList() {
        return mainMeetList;
    }

    public void setMainMeetList(List<RateDto> mainMeetList) {
        this.mainMeetList = mainMeetList;
    }

    public Probability getActCenter() {
        return actCenter;
    }

    public void setActCenter(Probability actCenter) {
        this.actCenter = actCenter;
    }

    public Probability getMainMeet() {
        return mainMeet;
    }

    public void setMainMeet(Probability mainMeet) {
        this.mainMeet = mainMeet;
    }

    public Probability getActivity() {
        return activity;
    }

    public void setActivity(Probability activity) {
        this.activity = activity;
    }

    public Probability getDirectPage() {
        return directPage;
    }

    public void setDirectPage(Probability directPage) {
        this.directPage = directPage;
    }

    public List<RateDto> getDirectPageList() {
        return directPageList;
    }

    public void setDirectPageList(List<RateDto> directPageList) {
        this.directPageList = directPageList;
    }

    /**
     * isSuitable:(概率和是否等于指定值，默认为100%). <br/>
     * @param persent
     * @return
     */
    public boolean isSuitable(Integer persent) {
        int suitable = persent == null ? 100 : persent;
        if (actCenter != null && mainMeet != null && directPage != null ) {
            int percent = actCenter.intPercentValue() + mainMeet.intPercentValue()+ directPage.intPercentValue();
            if(null != url){
                percent += url.intPercentValue();
            }
            if (percent == suitable) {
                return true;
            }
        }
        return false;
    }

    /***
         * @Description: isSuitableMainMeetList 判断主会场概率是否正确
         *
         * @Param: []
         * @Return: boolean
         * @throws:
         * @author: youhaijun
         * @Date:   2017/8/15
         */
    public boolean isSuitableMainMeetList()
    {
        if (0 != mainMeet.intPercentValue()){
            if(null == mainMeetList || mainMeetList.isEmpty()){
                return false;
            }
            int percent = 0;
            for(RateDto dto : mainMeetList){
                percent += dto.getRate();
            }
            if (100 == percent){
                return true;
            }
        }
        return false;
    }

    /**
     * selectMaxProbability:(查询概率最大的). <br/>
     * @return
     */
    public Integer selectMaxProbability() {
        int acp = 0;
        int ap = 0;
        int mp = 0;
        if (actCenter != null) {
            acp = actCenter.intPercentValue();
        }
        if (activity != null) {
            ap = activity.intPercentValue();
        }
        if (mainMeet != null) {
            mp = mainMeet.intPercentValue();
        }

        PageType rs = PageType.ACTIVITY;
        if (acp > ap) {
            rs = PageType.ACTCENTER;
            if (mp > acp) {
                rs = PageType.MAINMEET;
            }

        } else if (mp > ap) {
            rs = PageType.MAINMEET;
        }
        return rs.getCode();
    }
}

==> activity-center-api-0.8.4.3.y10-20180125.093327-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/ProbDto.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:Prob.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.dto<br>
 * Date:2017年3月29日下午8:54:03<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;
import cn.com.duiba.tuia.activity.center.api.common.Probability;
import cn.com.duiba.tuia.activity.center.api.constant.PageType;
import org.apache.commons.lang3.RandomUtils;

import java.util.List;

/**
 * ClassName: ProbDto <br/>
 * Function: 浮标跳转概率Dto. <br/>
 * Reason: . <br/>
 * date: 2017年3月29日 下午8:54:03 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class ProbDto extends BaseDto {

    private static final long serialVersionUID = 1L;
    /** actCenter:活动中心 概率. */
    private Probability       actCenter;
    /** mainMeet:主会场 概率. */
    private Probability       mainMeet;
    /** activity:活动 概率. */
    private Probability       activity;
    /** 直达变现页 概率.*/
    private Probability       directPage;

    /** url:活动 概率. */
    private Probability       url;

    private List<RateDto> urlList;

    /** 配置主会场页面概率.*/
    private List<RateDto> mainMeetList;

    /** 落地页url对应浮标. */
    private List<Long> buoyIdList;

    /** 配置直投页列表面概率.*/
    private List<RateDto> directPageList;

    public ProbDto() {
        super();
    }

    /**
     * 根据概率返回RateDto
     * @param list list
     * @param totalRate 总概率，没有则遍历list计算
     * @return RateDto
     */
    public static RateDto calRate(List<RateDto> list,Integer totalRate) {
        if (list == null || list.isEmpty()) {
            return null;
        }

        Integer total = totalRate;

        if (total == null) {
            total = sumRate(list);
        }

        if (total == null || total == 0) {
            return null;
        }

        int point = RandomUtils.nextInt(0, total) + 1;

        for (RateDto dto : list) {
            Integer rate = dto.getRate();
            if (rate == null || rate == 0) {
                continue;
            }
            if (rate >= point) {
                return dto;
            } else {
                point-=rate;
            }
        }
        return null;
    }

    /**
     * 计算概率和
     * @param list list
     * @return 概率和
     */
    public static Integer sumRate(List<RateDto> list) {
        int total = 0;
        if (list == null || list.isEmpty()) {
            return null;
        }
        for (RateDto dto : list) {
            Integer rate = dto.getRate();
            if (rate != null) {
                total += rate;
            }

        }
        return total;
    }

    public List<Long> getBuoyIdList() {
        return buoyIdList;
    }

    public void setBuoyIdList(List<Long> buoyIdList) {
        this.buoyIdList = buoyIdList;
    }

    public Probability getUrl() {
        return url;
    }

    public void setUrl(Probability url) {
        this.url = url;
    }

    public List<RateDto> getUrlList() {
        return urlList;
    }

    public void setUrlList(List<RateDto> urlList) {
        this.urlList = urlList;
    }

    public List<RateDto> getMainMeetList() {
        return mainMeetList;
    }

    public void setMainMeetList(List<RateDto> mainMeetList) {
        this.mainMeetList = mainMeetList;
    }

    public Probability getActCenter() {
        return actCenter;
    }

    public void setActCenter(Probability actCenter) {
        this.actCenter = actCenter;
    }

    public Probability getMainMeet() {
        return mainMeet;
    }

    public void setMainMeet(Probability mainMeet) {
        this.mainMeet = mainMeet;
    }

    public Probability getActivity() {
        return activity;
    }

    public void setActivity(Probability activity) {
        this.activity = activity;
    }

    public Probability getDirectPage() {
        return directPage;
    }

    public void setDirectPage(Probability directPage) {
        this.directPage = directPage;
    }

    public List<RateDto> getDirectPageList() {
        return directPageList;
    }

    public void setDirectPageList(List<RateDto> directPageList) {
        this.directPageList = directPageList;
    }

    /**
     * isSuitable:(概率和是否等于指定值，默认为100%). <br/>
     * @param persent
     * @return
     */
    public boolean isSuitable(Integer persent) {
        int suitable = persent == null ? 100 : persent;
        if (actCenter != null && mainMeet != null && directPage != null ) {
            int percent = actCenter.intPercentValue() + mainMeet.intPercentValue()+ directPage.intPercentValue();
            if(null != url){
                percent += url.intPercentValue();
            }
            if (percent == suitable) {
                return true;
            }
        }
        return false;
    }

    /***
         * @Description: isSuitableMainMeetList 判断主会场概率是否正确
         *
         * @Param: []
         * @Return: boolean
         * @throws:
         * @author: youhaijun
         * @Date:   2017/8/15
         */
    public boolean isSuitableMainMeetList()
    {
        if (0 != mainMeet.intPercentValue()){
            if(null == mainMeetList || mainMeetList.isEmpty()){
                return false;
            }
            int percent = 0;
            for(RateDto dto : mainMeetList){
                percent += dto.getRate();
            }
            if (100 == percent){
                return true;
            }
        }
        return false;
    }

    /**
     * selectMaxProbability:(查询概率最大的). <br/>
     * @return
     */
    public Integer selectMaxProbability() {
        int acp = 0;
        int ap = 0;
        int mp = 0;
        if (actCenter != null) {
            acp = actCenter.intPercentValue();
        }
        if (activity != null) {
            ap = activity.intPercentValue();
        }
        if (mainMeet != null) {
            mp = mainMeet.intPercentValue();
        }

        PageType rs = PageType.ACTIVITY;
        if (acp > ap) {
            rs = PageType.ACTCENTER;
            if (mp > acp) {
                rs = PageType.MAINMEET;
            }

        } else if (mp > ap) {
            rs = PageType.MAINMEET;
        }
        return rs.getCode();
    }
}
